﻿/*
Copyright (c) <2013>, Intel Corporation All Rights Reserved.

The source code, information and material ("Material") contained herein is 
owned by Intel Corporation or its suppliers or licensors, and title to such 
Material remains with Intel Corporation or its suppliers or licensors. The 
Material contains proprietary information of Intel or its suppliers and 
licensors. The Material is protected by worldwide copyright laws and treaty 
provisions. No part of the Material may be used, copied, reproduced, 
modified, published, uploaded, posted, transmitted, distributed or 
disclosed in any way without Intel's prior express written permission. No 
license under any patent, copyright or other intellectual property rights 
in the Material is granted to or conferred upon you, either expressly, by 
implication, inducement, estoppel or otherwise. Any license under such 
intellectual property rights must be express and approved by Intel in 
writing.

Copyright (c) <2013>, Microsoft All rights reserved.

Unless otherwise agreed by Intel in writing, you may not remove or alter 
this notice or any other notice embedded in Materials by Intel or Intel’s 
suppliers or licensors in any way.
*/

// For an introduction to the Blank template, see the following documentation:
// http://go.microsoft.com/fwlink/?LinkId=232509
(function () {
    "use strict";

    var gyroscope;

    var app = WinJS.Application;
    var activation = Windows.ApplicationModel.Activation;
    var img, ctx = null;
    var x_degrees = null, y_degrees = null, z_degrees = null;

    var dispRequest = null;

    // Activate the DisplayRequest prevents the device from entering sleep mode.
    // Call requestActive to notify Windows the app requires the display to remain on.
    // dispRequest code segment is taken from MSDN
    function ActivateDisplayLock() {
        if (dispRequest === null) {
            // Activate a display-required request. If successful, the screen is 
            // guaranteed not to turn off automatically due to user inactivity.
            dispRequest = new Windows.System.Display.DisplayRequest;
            dispRequest.requestActive();

            WinJS.log && WinJS.log("Display request activated",
                                   "sample",
                                   "status");
        }
    }

    // Release the DisplayRequest lets the device to enter sleep mode in set sleep time.
    // Call requestRelease to notify Windows the app does not require the display to remain on.
    // dispRequest code segment is taken from MSDN
    function ReleaseDisplayLock() {
        if (dispRequest != null) {
            // Deactivate the display request and set the var to null.
            dispRequest.requestRelease();
            dispRequest = null;

            WinJS.log && WinJS.log("Display request released",
                                               "sample",
                                               "status");

        }
    }

    app.onactivated = function (args) {
        if (args.detail.kind === activation.ActivationKind.launch) {
            if (args.detail.previousExecutionState !== activation.ApplicationExecutionState.terminated) {
                var minimumReportInterval;
                var reportInterval;

                gyroscope = Windows.Devices.Sensors.Gyrometer.getDefault(); //connect to the default gyrometer

                // Choose a report interval supported by the sensor
                minimumReportInterval = gyroscope.minimumReportInterval;
                //reportInterval changes the interval of sensor reading.
                //changed from default 16 to 64 (64 is based on experiment)
                reportInterval = minimumReportInterval > 64 ? minimumReportInterval : 64;
                gyroscope.reportInterval = reportInterval;

                // Set the event handler
                gyroscope.addEventListener("readingchanged", onDataChangedGyro);

                WinJS.UI.processAll();
            }
            args.setPromise(WinJS.UI.processAll());
        }
    };

    // This function is called each time a gyroscope event
    // is fired by the driver.
    function onDataChangedGyro(e) {
        var reading = e.reading;
        var thresholdVal = 2.00;

        document.getElementById('message').innerHTML = "Display Lock is Activated";

        // Sensitivity varies from device to device.
        // If the sensor reading is +/-2.00 of a current sensor reading, the app is not in use 
        // and can go to sleep mode. Since this is a gyroscope, x,y,z will be zero +/- threshold in any position at rest.
        if ((x_degrees <= thresholdVal) & (x_degrees >= -thresholdVal) &
            (y_degrees <= thresholdVal) & (y_degrees >= -thresholdVal) &
            (z_degrees <= thresholdVal) & (z_degrees >= -thresholdVal)) {
 
            // Release Display Lock
            ReleaseDisplayLock();    
            document.getElementById('message').innerHTML = "Releasing Display Lock";
        } else {
            // Activate Display Lock
            ActivateDisplayLock();
        }

        x_degrees = reading.angularVelocityX.toFixed(2);
        y_degrees = reading.angularVelocityY.toFixed(2);
        z_degrees = reading.angularVelocityZ.toFixed(2);

        id('txtXVelocity').innerHTML = x_degrees;
        id('txtYVelocity').innerHTML = y_degrees;
        id('txtZVelocity').innerHTML = z_degrees;

        id('reportInterval').innerHTML = gyroscope.reportInterval;

        id('gyroscope').style.msTransform = 'perspective(0px) translate3d(100px, 0px, 0px) rotateX(' + x_degrees + 'deg) rotateY(' + y_degrees + 'deg) rotateZ(' + z_degrees + 'deg)';
    }

    // This function is invoked within onDataChanged to
    // retrieve the given identifier from the HTML document.
    function id(elementId) {
        return document.getElementById(elementId);
    }

    app.oncheckpoint = function (args) {
    };

    app.start();
})();